#include "mbed.h"
#include "stdio.h"


#define HIGH 1
#define LOW 0

Serial pc(USBTX,USBRX);//USBTX = PTA2, USBRX = PTA1,

DigitalOut I2C_CLK (PTC1);
DigitalInOut I2C_DATA (PTC2);

void delay()
{
	wait_us(1);
}

void I2C_START(void)
{
	I2C_DATA.output();
	I2C_DATA = HIGH;
	I2C_CLK = HIGH;
	I2C_DATA = LOW;
	I2C_CLK = LOW;
}

void I2C_STOP (void)
{
	I2C_DATA.output();
	I2C_CLK = LOW;
	I2C_DATA = LOW;
	I2C_CLK = HIGH;
	I2C_DATA = HIGH;
}

int I2C_WRITE(unsigned char data)
{
	int ack=0;
	I2C_DATA.output();

	unsigned char outBits;

	/* 8 bits */
	for(outBits = 0; outBits < 8; outBits++)
	{
		if(data & 0x80)
			I2C_DATA = 1;
		else
			I2C_DATA = 0;
		data  <<= 1;
		/* Generate clock for 8 data bits */
		I2C_CLK = HIGH;
		I2C_CLK = LOW;
	}

	/* Generate clock for ACK */
	I2C_CLK = HIGH;

	I2C_DATA.input(); //To check ack

	/* Clock high, valid ACK */
	ack = I2C_DATA;

	I2C_CLK = LOW;

	return ack;
}

unsigned char I2C_READ (void)
{
	I2C_DATA.input();

	unsigned char inData, inBits;

	inData = 0x00;
	/* 8 bits */
	for(inBits = 0; inBits < 8; inBits++)
	{
		inData <<= 1;
		I2C_CLK = HIGH;
		inData |= I2C_DATA;
		I2C_CLK = LOW;
	}

	return inData;
}


void writeI2CSlave (unsigned char data)
{
	/* Start */
	I2C_START();
	/* Slave address */
	I2C_WRITE(0xAA);
	/* Slave control byte */
	I2C_WRITE(0xBB);
	/* Slave data */
	I2C_WRITE(data);
	/* Stop */
	I2C_STOP();
}


unsigned char readI2CSlave(unsigned char data)
{
	unsigned char inData;

	/* Start */
	I2C_START();
	/* Slave address */
	I2C_WRITE(0xAA);
	/* Slave control byte */
	I2C_WRITE(data);
	/* Stop */
	I2C_STOP();

	/* Start */
	I2C_START();
	/* Slave address + read */
	I2C_WRITE(0xAA | 1);
	/* Read */
	inData = I2C_READ();

	return inData;
}

void lvds_init(void)
{
	I2C_START();

	//Write Address
	if(I2C_WRITE(0x5B))
	{
		pc.printf("\r\nNack");
	}
	else
	{
//		pc.printf("\r\nAck");

		// Write Sub-Address
		if(I2C_WRITE(0x0A))
		{
			pc.printf("\r\nNack");
		}
		else
		{
			pc.printf("\r\nAck");
			unsigned char data=I2C_READ();
			printf("\r\nData=%02X",data);
		}
	}
	I2C_STOP();
}

int main()
{
	pc.baud(115200);
	pc.printf("\r\n\nStart");
	wait_ms(50);

	lvds_init();

	while(1)
	{


	}
}
